"""
#########################################################
:mod:`pywebtools.kajiki` -- Utilities for use with Kajiki
#########################################################

This module provides two function definition templates "form.kajiki"
and "menu.kajiki".

form.kajiki
===========

Helper functions for creating HTML input elements.

.. py:function:: input(field_type, field_name, **kwargs)

   Generates a HTML input field with the given ``field_type`` and ``field_name``.
   The ``kwargs`` contains additional parameters::

   * value: The default value or the value of a checkbox/radio/select input
   * values: List of (value, label) pairs for use with a select input
   * extra_attrs: Dictionary of additional HTML element attribute key/value pairs

   Additionally if a ``values`` dictionary is in the current view, then this will
   be used to set any input values. This can be used to pre-fill the form with
   existing data.

   :param field_type: The HTML field type to generate
   :type field_type: ``str``
   :param field_name: The name of the HTML field
   :type field_name: ``str``
   :param kwargs: Additional keyword arguments as described above

.. py:function:: field(field_type, field_name, field_label, **kwargs)

   Generates a HTML input field with wrapping <label> using the ``field_label``
   value. Sets Foundation / Abide CSS classes if there is an ``errors`` dictionary
   in the current view and the ``field_name`` occurs in that dictionary. Will
   also output the matching error message.

   :param field_type: The HTML field type to generate
   :type field_type: ``str``
   :param field_name: The name of the HTML field
   :type field_name: ``str``
   :param field_name: The displayed label of the HTML field
   :type field_name: ``str``
   :param kwargs: Additional keyword arguments as described in :func:`~pywebtools.kajiki.input`

.. py:function:: csrf_field()

   Generates a hidden input field with the name "csrf_token" and the value set to the
   current session's CSRF token. Integrates with the :class:`pywebtools.formencode.CSRFSchema`.

menu.kajiki
===========

Helper function for creating an icon-based menu-bar.

.. py:function:: menubar(groups, class_=None, alignment='left')

   Generates the HTML structure for a Foundation dropdown menu using icons for the top level
   and text for the drop-down items.

   :params groups: The list of groups generated by the :class:`~pywebtools.pyramid.util.MenuBuilder`
   :type groups: ``list``
   :param class_: An optional CSS class to set on the menu's <ul> element
   :type class_: ``str``
   :param alignment: The alignment of the drop-down items. Defaults to "left", can be set to "right"
   :type alignment: ``str``

.. moduleauthor:: Mark Hall <mark.hall@work.room3b.eu>
"""
